<?php
class HhContentVars extends Module {
 
    public function __construct() {
        $this->name = 'hhcontentvars';
        $this->tab = 'others';
        $this->author = 'hhennes';
        $this->version = '1.0.0';
        $this->need_instance = 0;
        $this->bootstrap = true;
 
        parent::__construct();
 
        $this->displayName = $this->l('Hh content var');
        $this->description = $this->l('Add content var in wysiwyg editors');
    }
 
    public function install() {
        if (!parent::install() 
                //Hooks Fronts d'affichage
                || !$this->registerHook('filterCmsContent') 
                || !$this->registerHook('filterCmsCategoryContent') 
                || !$this->registerHook('filterProductContent') 
                || !$this->registerHook('filterCategoryContent') 
                || !$this->registerHook('filterManufacturerContent') 
                || !$this->registerHook('filterSupplierContent')
        )
            return false;
 
        return true;
    }
 
 
    /**
     * Filtre des contenus Cms
     * @param $params
     * @return array
     */
    public function hookFilterCmsContent($params) {
 
        $params['object']['content'] = $this->_updateContentVars($params['object']['content']);
 
        return [
            'object' => $params['object']
        ];
    }
 
    /**
     * Filtre des contenus des catégories cms
     * @param $params
     * @return array
     */
    public function hookFilterCmsCategoryContent($params) {
 
        $params['object']['description'] = $this->_updateContentVars($params['object']['description']);
 
        return [
            'object' => $params['object']
        ];
    }
 
    /**
     * Filtre des contenu des produits
     * @param $params
     */
    public function hookFilterProductContent($params) {
        $params['object']['description'] = $this->_updateContentVars($params['object']['description']);
        return [
            'object' => $params['object']
        ];
    }
 
    /**
     * Filtre des contenus des catégories produits
     * @param $params
     * @return array
     */
    public function hookFilterCategoryContent($params) {
 
        $params['object']['description'] = $this->_updateContentVars($params['object']['description']);
 
        return [
            'object' => $params['object']
        ];
    }
 
    /**
     * Filtre des contenus des Marques
     * @param $params
     * @return mixed
     */
    public function hookFilterManufacturerContent($params) {
 
        return $this->_updateContentVars($params['filtered_content']);
    }
 
    /**
     * Filtre des contenus des fournisseurs
     * @param $params
     * @return array
     */
    public function hookFilterSupplierContent($params) {
        $params['object']['description'] = $this->_updateContentVars($params['object']['description']);
 
        return [
            'object' => $params['object']
        ];
    }
 
    /**
     * Mise à jour du contenu
     * @param string : contenu ou il faut remplacer les variables
     * @return string : contenu avec les variables remplacées
     */
    protected function _updateContentVars($content) {
 
        $content = urldecode($content);
 
        //Récupération des éléments de configuration
        preg_match_all('#{{configuration name=(.*)}}#i', $content, $configurations);
        if (isset($configurations[1]) && sizeof($configurations[1])) {
            foreach ($configurations[1] as $conf) {
                if ( $value = Configuration::get($conf) ) {
                    $content = preg_replace('#{{configuration name=' . $conf . '}}#',$value, $content);
                }
            }
        }
 
        return $content;
    }
}